summaryrefslogtreecommitdiff
path: root/modules/field/field.api.php
diff options
context:
space:
mode:
Diffstat (limited to 'modules/field/field.api.php')
-rw-r--r--modules/field/field.api.php23
1 files changed, 6 insertions, 17 deletions
diff --git a/modules/field/field.api.php b/modules/field/field.api.php
index 3728ba226..db37d8758 100644
--- a/modules/field/field.api.php
+++ b/modules/field/field.api.php
@@ -1064,15 +1064,8 @@ function hook_field_attach_pre_update($obj_type, $object, &$skip_fields) {
* A storage module that doesn't support querying a given column should raise
* a FieldQueryException. Incompatibilities should be mentioned on the module
* project page.
- * @param $count
- * See field_attach_query().
- * @param $cursor
- * See field_attach_query().
- * @param $age
- * - FIELD_LOAD_CURRENT: query the most recent revisions for all
- * objects. The results will be keyed by object type and object id.
- * - FIELD_LOAD_REVISION: query all revisions. The results will be keyed by
- * object type and object revision id.
+ * @param $options
+ * See field_attach_query(). All option keys are guaranteed to be specified.
* @param $skip_field
* Boolean, always coming as FALSE.
* @return
@@ -1080,7 +1073,7 @@ function hook_field_attach_pre_update($obj_type, $object, &$skip_fields) {
* The $skip_field parameter should be set to TRUE if the query has been
* handled.
*/
-function hook_field_attach_pre_query($field_name, $conditions, $count, &$cursor = NULL, $age, &$skip_field) {
+function hook_field_attach_pre_query($field_name, $conditions, $options, &$skip_field) {
}
/**
@@ -1331,16 +1324,12 @@ function hook_field_storage_delete_revision($obj_type, $object, $fields) {
* A storage module that doesn't support querying a given column should raise
* a FieldQueryException. Incompatibilities should be mentioned on the module
* project page.
* @param $count
* See field_attach_query().
* @param $cursor
* See field_attach_query().
* @param $age
* See field_attach_query().
* @return
* See field_attach_query().
*/
-function hook_field_storage_query($field_name, $conditions, $count, &$cursor = NULL, $age) {
+function hook_field_storage_query($field_name, $conditions, $options) {
}
/**
@@ -1331,16 +1324,12 @@ function hook_field_storage_delete_revision($obj_type, $object, $fields) {
* a FieldQueryException. Incompatibilities should be mentioned on the module
* project page.
- * @param $count
- * See field_attach_query().
- * @param $cursor
- * See field_attach_query().
- * @param $age
- * See field_attach_query().
+ * @param $options
+ * See field_attach_query(). All option keys are guaranteed to be specified.
* @return
* See field_attach_query().